from typing import TypedDict


class WindowsServer(TypedDict):
    r"""
- Contains remote Powershell connection details for a Windows Server

- It is used as an _input_ to many of the actions in this plugin

- The example below shows the dictionary structure in YAML

- See the ___required___ and _optional_ keys underneath the example

!!! warning "Supplying Credentials"

    You should ___always___ use a PPA Vault integration to provide credentials to a plugin action.

!!! example

    ```yaml linenums="1"
    windows_server:
      address: windows-server.internal.net
      username: example.username
      password: example.password
      validate_cert: true
      use_ssl: true
    ```

???+ danger "Required Keys"

    __address__: The target IP or DNS address.

    __username__: Username for authentication.

    __password__: Password for authentication.

    __validate_cert__: Set to _false_ to skip certificate validation (defaults to _true_).

    __use_ssl__: Set to _false_ to connect over HTTP (defaults to _true_ using HTTPS).
    """
    address: str
    username: str
    password: str
    validate_cert: bool
    use_ssl: bool
